@@ -55,6 +55,8 @@ def _season_type_from_name(name: str) -> SeasonType:
 class ESPNLeagueModel(LeagueModel):
     """ESPN implementation of the league model."""
 
+    _found_games: set[str]
+
     def __init__(
         self,
         start_url: str,
@@ -64,6 +66,7 @@ class ESPNLeagueModel(LeagueModel):
     ) -> None:
         super().__init__(league, session, position=position)
         self._start_url = start_url
+        self._found_games = set()
 
     @classmethod
     def name(cls) -> str:
@@ -102,11 +105,20 @@ class ESPNLeagueModel(LeagueModel):
 
         for competition in competitions:
             if "status" in competition:
-                status_response = self.session.get(competition["status"]["$ref"])
+                if cache_disabled:
+                    with self.session.cache_disabled():
+                        status_response = self.session.get(
+                            competition["status"]["$ref"]
+                        )
+                else:
+                    status_response = self.session.get(competition["status"]["$ref"])
                 status_response.raise_for_status()
                 status = status_response.json()
                 if not status["type"]["completed"]:
                     continue
+            competition_ref = competition["$ref"]
+            if competition_ref in self._found_games:
+                continue
             game_model = create_espn_game_model(
                 competition,
                 week_count,
@@ -123,6 +135,7 @@ class ESPNLeagueModel(LeagueModel):
                 f"ESPN {game_model.year} - {game_model.season_type} - {game_model.dt}"
             )
             yield game_model
+            self._found_games.add(competition_ref)
 
     def _produce_games(
         self,
@@ -137,9 +150,15 @@ class ESPNLeagueModel(LeagueModel):
         while True:
             if "events" not in week:
                 break
-            events_response = self.session.get(
-                week["events"]["$ref"] + f"&page={events_page}"
-            )
+            if cache_disabled:
+                with self.session.cache_disabled():
+                    events_response = self.session.get(
+                        week["events"]["$ref"] + f"&page={events_page}"
+                    )
+            else:
+                events_response = self.session.get(
+                    week["events"]["$ref"] + f"&page={events_page}"
+                )
             events_response.raise_for_status()
             events = events_response.json()
             for event_item in events["items"]:
@@ -161,7 +180,15 @@ class ESPNLeagueModel(LeagueModel):
         while True:
             if "qbr" not in week:
                 break
-            qbr_response = self.session.get(week["qbr"]["$ref"] + f"&page={qbr_page}")
+            if cache_disabled:
+                with self.session.cache_disabled():
+                    qbr_response = self.session.get(
+                        week["qbr"]["$ref"] + f"&page={qbr_page}"
+                    )
+            else:
+                qbr_response = self.session.get(
+                    week["qbr"]["$ref"] + f"&page={qbr_page}"
+                )
             qbr = qbr_response.json()
             for qbr_item in qbr["items"]:
                 for game_model in self._produce_game(
@@ -298,6 +325,7 @@ class ESPNLeagueModel(LeagueModel):
 
     @property
     def games(self) -> Iterator[GameModel]:
+        self._found_games = set()
         try:
             with self.session.wayback_disabled():
                 page = 1
@@ -316,14 +344,24 @@ class ESPNLeagueModel(LeagueModel):
                         response.raise_for_status()
                         seasons = response.json()
                         for item in seasons.get("items", []):
-                            season_response = self.session.get(item["$ref"])
+                            if first:
+                                with self.session.cache_disabled():
+                                    season_response = self.session.get(item["$ref"])
+                            else:
+                                season_response = self.session.get(item["$ref"])
                             season_response.raise_for_status()
                             season_json = season_response.json()
 
                             for season_item in season_json["types"]["items"]:
-                                season_type_response = self.session.get(
-                                    season_item["$ref"]
-                                )
+                                if first:
+                                    with self.session.cache_disabled():
+                                        season_type_response = self.session.get(
+                                            season_item["$ref"]
+                                        )
+                                else:
+                                    season_type_response = self.session.get(
+                                        season_item["$ref"]
+                                    )
                                 season_type_response.raise_for_status()
                                 season_type_json = season_type_response.json()
 
