@@ -39,7 +39,11 @@ class FootballDataLeagueModel(LeagueModel):
         return {str(x): str(x) for x in Position}
 
     def _row_to_game(self, row: Any) -> GameModel | None:
-        division_cell = row.get("Div")
+        div_headers = [x for x in row.keys() if x is not None and x.endswith("Div")]
+        if not div_headers:
+            return None
+        div_header = div_headers[0]
+        division_cell = row.get(div_header)
         if division_cell not in {"E0", "D1", "SP1"}:
             return None
         date_cell = str(row["Date"]).strip()
@@ -92,6 +96,9 @@ class FootballDataLeagueModel(LeagueModel):
         away_odds_cell = row.get("B365A")
         if away_odds_cell is not None and not away_odds_cell:
             away_odds_cell = None
+        draw_odds_cell = row.get("B365D")
+        if draw_odds_cell is not None and not draw_odds_cell:
+            draw_odds_cell = None
 
         return create_footballdata_game_model(
             session=self.session,
@@ -115,6 +122,7 @@ class FootballDataLeagueModel(LeagueModel):
             away_red_cards=away_red_cards_cell,
             home_odds=home_odds_cell,
             away_odds=away_odds_cell,
+            draw_odds=draw_odds_cell,
         )
 
     @property
@@ -165,14 +173,11 @@ class FootballDataLeagueModel(LeagueModel):
                         ):
                             csv_urls.append(csv_url)
 
+                    logging.info("CSV URLs: %s", " - ".join(csv_urls))
                     for count, csv_url in enumerate(sorted(csv_urls)):
                         logging.info("Processing %s", csv_url)
                         response = None
-                        if count <= 5:
-                            with self.session.cache_disabled():
-                                self.session.cache.delete(urls=[csv_url])
-                                response = self.session.get(csv_url)
-                        else:
+                        with self.session.cache_disabled():
                             response = self.session.get(csv_url)
                         response.raise_for_status()
                         handle = io.StringIO(response.text)
