@@ -437,6 +437,18 @@ NFL_VENUE_IDENTITY_MAP = {
     "GEHA FIELD AT ARROWHEAD STADIUM": ARROWHEAD_STADIUM,
     "MERCEDES-BENZ STADIUM": MERCEDEZ_BENZ_STADIUM,
     "NORTHWEST STADIUM": FEDEX_FIELD,
+    "FORD FIELD": FORD_FIELD,
+    "LEVI'S® STADIUM": LEVIS_STADIUM,
+    "AT&T STADIUM": ATT_STADIUM,
+    "EMPOWER FIELD AT MILE HIGH": EMPOWER_FIELD,
+    "NISSAN STADIUM": NISSAN_STADIUM,
+    "U.S. BANK STADIUM": US_BANK_STADIUM,
+    "HUNTINGTON BANK FIELD": HUNTINGTON_BANK_FIELD,
+    "SOLDIER FIELD": SOLDIER_FIELD,
+    "WEMBLEY STADIUM": WEMBLEY_STADIUM,
+    "NRG STADIUM": NRG_STADIUM,
+    "GILLETTE STADIUM": GILETTE_STADIUM,
+    "OLYMPIC STADIUM": OLYMPIC_STADIUM_BERLIN,
 }
 NFL_PLAYER_IDENTITY_MAP: dict[str, str] = {}
 
